If

Struct If 

pub struct If { /* private fields */ }
If is a structured control flow operation representing conditional execution.

An If takes a single condition as an argument, which chooses between one of its two regions based on the condition. If the condition is true, then the then_body region is executed, otherwise else_body.

Neither region allows any arguments, and both regions must be terminated with one of:

Implementations

Source

impl If

Construction

pub fn create<B: ?Sized + Builder>( builder: &mut B, span: SourceSpan, condition: ValueRef, ) -> Result<UnsafeIntrusiveEntityRef<Self>, Report>

Manually construct a new If

It is generally preferable to use ::midenc_hir::BuilderExt::create instead.

pub fn alloc_default(context: Rc<Context>) -> UnsafeIntrusiveEntityRef<Self>

Allocate a new, default-initialized If

This method is used as part of op definition implementation, and should not be used directly if at all possible.

Source

impl If

This impl block contains no public items.

User-defined Fields

Source

impl If

This impl block contains no public items.

Attributes

Source

impl If

This impl block contains no public items.

Symbols

Source

impl If

Operands

pub fn condition(&self) -> EntityRef<'_, OpOperandImpl>

Get a reference to the condition operand.

pub fn condition_mut(&mut self) -> EntityMut<'_, OpOperandImpl>

Get a mutable reference to the condition operand.

Source

impl If

Results

pub fn returns(&self) -> OpResultRange<'_>

Get a reference to the returns result group.

pub fn returns_mut(&mut self) -> OpResultRangeMut<'_>

Get a mutable reference to the returns result group.

Source

impl If

Regions

pub fn then_body(&self) -> EntityRef<'_, Region>

Get a reference to the then_body region.

pub fn then_body_mut(&mut self) -> EntityMut<'_, Region>

Get a mutable reference to the then_body region.

pub fn else_body(&self) -> EntityRef<'_, Region>

Get a reference to the else_body region.

pub fn else_body_mut(&mut self) -> EntityMut<'_, Region>

Get a mutable reference to the else_body region.

Source

impl If

This impl block contains no public items.

Successors

Source

impl If