pub struct While { /* private fields */ }Expand description
A while is a loop structure composed of two regions: a “before” region, and an “after” region.
The “before” region’s entry block parameters correspond to the operands expected by the operation, and can be used to compute the condition that determines whether the “after” body is executed or not, or simply forwarded to the “after” region. The “before” region must terminate with a Condition operation, which will be evaluated to determine whether or not to continue the loop.
The “after” region corresponds to the loop body, and must terminate with a Yield operation, whose operands must be of the same arity and type as the “before” region’s argument list. In this way, the “after” body can feed back input to the “before” body to determine whether to continue the loop.
Implementations
Sourceimpl While
Construction
impl While
Construction
Sourcepub fn create<B: ?Sized + Builder, TInits: IntoIterator<Item = ValueRef>>(
builder: &mut B,
span: SourceSpan,
inits: TInits,
) -> Result<UnsafeIntrusiveEntityRef<Self>, Report>
pub fn create<B: ?Sized + Builder, TInits: IntoIterator<Item = ValueRef>>( builder: &mut B, span: SourceSpan, inits: TInits, ) -> Result<UnsafeIntrusiveEntityRef<Self>, Report>
Manually construct a new While
It is generally preferable to use ::midenc_hir::BuilderExt::create instead.
Sourcepub fn alloc_default(context: Rc<Context>) -> UnsafeIntrusiveEntityRef<Self>
pub fn alloc_default(context: Rc<Context>) -> UnsafeIntrusiveEntityRef<Self>
Allocate a new, default-initialized While
This method is used as part of op definition implementation, and should not be used directly if at all possible.
impl While
User-defined Fields
impl While
Attributes
impl While
Symbols
Sourceimpl While
Operands
impl While
Operands
Sourcepub fn inits(&self) -> OpOperandRange<'_>
pub fn inits(&self) -> OpOperandRange<'_>
Get a reference to the inits operand group.
Sourcepub fn inits_mut(&mut self) -> OpOperandRangeMut<'_>
pub fn inits_mut(&mut self) -> OpOperandRangeMut<'_>
Get a mutable reference to the inits operand group.
Sourceimpl While
Results
impl While
Results
Sourcepub fn returns(&self) -> OpResultRange<'_>
pub fn returns(&self) -> OpResultRange<'_>
Get a reference to the returns result group.
Sourcepub fn returns_mut(&mut self) -> OpResultRangeMut<'_>
pub fn returns_mut(&mut self) -> OpResultRangeMut<'_>
Get a mutable reference to the returns result group.
Sourceimpl While
Regions
impl While
Regions
Sourcepub fn before_mut(&mut self) -> EntityMut<'_, Region>
pub fn before_mut(&mut self) -> EntityMut<'_, Region>
Get a mutable reference to the before region.
impl While
Successors
Sourceimpl While
impl While
pub fn condition_op(&self) -> UnsafeIntrusiveEntityRef<Condition>
pub fn yield_op(&self) -> UnsafeIntrusiveEntityRef<Yield>