pub struct If { /* private fields */ }Expand description
If is a structured control flow operation representing conditional execution.
An If takes a single condition as an argument, which chooses between one of its two regions
based on the condition. If the condition is true, then the then_body region is executed,
otherwise else_body.
Neither region allows any arguments, and both regions must be terminated with one of:
- midenc_hir::dialects::builtin::Ret to return from the enclosing function directly
midenc_dialect_ub::Unreachableto abort execution- Yield to return from the enclosing If
Implementations
Sourceimpl If
Construction
impl If
Construction
Sourcepub fn create<B: ?Sized + Builder>(
builder: &mut B,
span: SourceSpan,
condition: ValueRef,
) -> Result<UnsafeIntrusiveEntityRef<Self>, Report>
pub fn create<B: ?Sized + Builder>( builder: &mut B, span: SourceSpan, condition: ValueRef, ) -> Result<UnsafeIntrusiveEntityRef<Self>, Report>
Manually construct a new If
It is generally preferable to use ::midenc_hir::BuilderExt::create instead.
Sourcepub fn alloc_default(context: Rc<Context>) -> UnsafeIntrusiveEntityRef<Self>
pub fn alloc_default(context: Rc<Context>) -> UnsafeIntrusiveEntityRef<Self>
Allocate a new, default-initialized If
This method is used as part of op definition implementation, and should not be used directly if at all possible.
impl If
User-defined Fields
impl If
Attributes
impl If
Symbols
Sourceimpl If
Operands
impl If
Operands
Sourcepub fn condition(&self) -> EntityRef<'_, OpOperandImpl>
pub fn condition(&self) -> EntityRef<'_, OpOperandImpl>
Get a reference to the condition operand.
Sourcepub fn condition_mut(&mut self) -> EntityMut<'_, OpOperandImpl>
pub fn condition_mut(&mut self) -> EntityMut<'_, OpOperandImpl>
Get a mutable reference to the condition operand.
Sourceimpl If
Results
impl If
Results
Sourcepub fn returns(&self) -> OpResultRange<'_>
pub fn returns(&self) -> OpResultRange<'_>
Get a reference to the returns result group.
Sourcepub fn returns_mut(&mut self) -> OpResultRangeMut<'_>
pub fn returns_mut(&mut self) -> OpResultRangeMut<'_>
Get a mutable reference to the returns result group.
Sourceimpl If
Regions
impl If
Regions
Sourcepub fn then_body_mut(&mut self) -> EntityMut<'_, Region>
pub fn then_body_mut(&mut self) -> EntityMut<'_, Region>
Get a mutable reference to the then_body region.
Sourcepub fn else_body_mut(&mut self) -> EntityMut<'_, Region>
pub fn else_body_mut(&mut self) -> EntityMut<'_, Region>
Get a mutable reference to the else_body region.
impl If
Successors
Sourceimpl If
impl If
pub fn then_yield(&self) -> UnsafeIntrusiveEntityRef<Yield>
pub fn else_yield(&self) -> UnsafeIntrusiveEntityRef<Yield>